import { CommonModule } from '@angular/common';
import { Observable } from 'rxjs';
import { Component, ElementRef, HostBinding, Injectable, ComponentFactoryResolver, ApplicationRef, Injector, Input, ViewChild, Renderer2, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SliderCarouselPreviewComponent {
    /**
     * @param {?} elRef
     */
    constructor(elRef) {
        this.elRef = elRef;
        this.class = true;
        this.closedClass = false;
        this.imageUrl = '';
        this.loading = true;
        this.scaleRate = 1;
        this.modalRef = {};
    }
    /**
     * @return {?}
     */
    get width() { return (this.loading ? 0 : this.img.width * this.scaleRate) + 'px'; }
    /**
     * @return {?}
     */
    get height() { return (this.loading ? 0 : this.img.height * this.scaleRate) + 'px'; }
    /**
     * @private
     * @return {?}
     */
    get windowWidth() { return window.innerWidth - 40; }
    /**
     * @private
     * @return {?}
     */
    get windowHeight() { return window.innerHeight - 40; }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.imageUrl = this.modalRef.imageUrl;
        this.loadImage();
    }
    /**
     * @private
     * @return {?}
     */
    loadImage() {
        this.loading = true;
        this.img = new Image();
        this.img.onload = (/**
         * @return {?}
         */
        () => {
            this.loading = false;
            this.onWindowResize();
        });
        this.img.src = this.imageUrl;
    }
    /**
     * @param {?} imageUrl
     * @param {?=} fileName
     * @return {?}
     */
    onImageChange(imageUrl, fileName) {
        if (!this.loading && this.imageUrl !== imageUrl) {
            this.imageUrl = imageUrl;
            this.loadImage();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeydown(event) {
        event.preventDefault();
        event.stopImmediatePropagation();
        if (event.keyCode === 27)
            this.close();
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        if (!this.loading) {
            /** @type {?} */
            let widthDiff = this.windowWidth - this.img.width;
            /** @type {?} */
            let heightDiff = this.windowHeight - this.img.height;
            if (widthDiff < 0 || heightDiff < 0) {
                if (widthDiff < heightDiff) {
                    if (this.img.width > this.windowWidth) {
                        this.scaleRate = this.windowWidth / this.img.width;
                        return;
                    }
                }
                else {
                    if (this.img.height > this.windowHeight) {
                        this.scaleRate = this.windowHeight / this.img.height;
                        return;
                    }
                }
            }
        }
        this.scaleRate = 1;
    }
    /**
     * @return {?}
     */
    close() {
        this.closedClass = true;
        setTimeout((/**
         * @return {?}
         */
        () => this.modalRef.close()), 500);
    }
}
SliderCarouselPreviewComponent.decorators = [
    { type: Component, args: [{
                selector: 'slider-carousel-preview',
                template: "<section *ngIf=\"!loading\">\r\n    <img [src]=\"imageUrl\" [style.width]=\"width\" [style.height]=\"height\" />\r\n    <div class=\"slider-carousel-preview-actions\">\r\n        <button matRipple matTooltipPosition=\"above\" (click)=\"close()\">\r\n            <svg x=\"0px\" y=\"0px\" viewBox=\"0 0 51.976 51.976\">\r\n                <path d=\"M44.373,7.603c-10.137-10.137-26.632-10.138-36.77,0c-10.138,10.138-10.137,26.632,0,36.77s26.632,10.138,36.77,0\r\n                    C54.51,34.235,54.51,17.74,44.373,7.603z M36.241,36.241c-0.781,0.781-2.047,0.781-2.828,0l-7.425-7.425l-7.778,7.778\r\n                    c-0.781,0.781-2.047,0.781-2.828,0c-0.781-0.781-0.781-2.047,0-2.828l7.778-7.778l-7.425-7.425c-0.781-0.781-0.781-2.048,0-2.828\r\n                    c0.781-0.781,2.047-0.781,2.828,0l7.425,7.425l7.071-7.071c0.781-0.781,2.047-0.781,2.828,0c0.781,0.781,0.781,2.047,0,2.828\r\n                    l-7.071,7.071l7.425,7.425C37.022,34.194,37.022,35.46,36.241,36.241z\"/>\r\n            </svg>\r\n        </button>\r\n    </div>\r\n</section>\r\n<div *ngIf=\"loading\" class=\"slider-carousel-loading\"></div>",
                host: {
                    '(document:keydown)': 'onKeydown($event)',
                    '(window:resize)': 'onWindowResize()'
                }
            }] }
];
/** @nocollapse */
SliderCarouselPreviewComponent.ctorParameters = () => [
    { type: ElementRef }
];
SliderCarouselPreviewComponent.propDecorators = {
    class: [{ type: HostBinding, args: ['class.slider-carousel-preview',] }],
    closedClass: [{ type: HostBinding, args: ['class.closed',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Helper {
    /**
     * @param {?} componentFactoryResolver
     * @param {?} appRef
     * @param {?} injector
     */
    constructor(componentFactoryResolver, appRef, injector) {
        this.componentFactoryResolver = componentFactoryResolver;
        this.appRef = appRef;
        this.injector = injector;
    }
    /**
     * @param {?=} data
     * @return {?}
     */
    openPreview(data = {}) {
        /** @type {?} */
        let onCloseSubscribe;
        /** @type {?} */
        let object;
        object = {
            onClose: new Observable((/**
             * @param {?} subscribe
             * @return {?}
             */
            (subscribe) => onCloseSubscribe = subscribe)),
            instance: null
        };
        /** @type {?} */
        let componenRef = this.createComponent(SliderCarouselPreviewComponent, data, (/**
         * @param {?} data
         * @return {?}
         */
        (data) => {
            onCloseSubscribe.next(data);
        }));
        object.instance = ((/** @type {?} */ (componenRef))).instance;
        return object;
    }
    /**
     * @param {?} component
     * @param {?} data
     * @param {?} onClose
     * @return {?}
     */
    createComponent(component, data, onClose) {
        /** @type {?} */
        const componentRef = this.componentFactoryResolver
            .resolveComponentFactory(component)
            .create(this.injector);
        if (!data)
            data = {};
        data.close = (/**
         * @param {?} data
         * @return {?}
         */
        (data) => {
            this.appRef.detachView(componentRef.hostView);
            componentRef.destroy();
            if (onClose)
                onClose(data);
        });
        Object.assign(componentRef.instance, { modalRef: data });
        this.appRef.attachView(componentRef.hostView);
        /** @type {?} */
        const domElem = (/** @type {?} */ (((/** @type {?} */ (componentRef.hostView))).rootNodes[0]));
        document.body.appendChild(domElem);
        return componentRef;
    }
    /**
     * @param {?} element
     * @param {?} scroll
     * @param {?=} duration
     * @param {?=} direction
     * @return {?}
     */
    smoothScroll(element, scroll, duration = 400, direction = 'top') {
        /** @type {?} */
        let start = direction === 'top' ? element.scrollTop : element.scrollLeft;
        if (scroll < 0)
            scroll = 0;
        /** @type {?} */
        let distance = (scroll - start) - 77;
        /** @type {?} */
        let startTime = new Date().getTime();
        if (!duration)
            duration = 400;
        /** @type {?} */
        let easeInOutQuart = (/**
         * @param {?} time
         * @param {?} from
         * @param {?} distance
         * @param {?} duration
         * @return {?}
         */
        (time, from, distance, duration) => {
            if ((time /= duration / 2) < 1)
                return distance / 2 * time * time * time * time + from;
            return -distance / 2 * ((time -= 2) * time * time * time - 2) + from;
        });
        /** @type {?} */
        let timer = setInterval((/**
         * @return {?}
         */
        () => {
            /** @type {?} */
            const time = new Date().getTime() - startTime;
            /** @type {?} */
            const newScroll = easeInOutQuart(time, start, distance, duration);
            if (time >= duration) {
                clearInterval(timer);
                timer = null;
            }
            if (element.scrollTo) {
                if (direction === 'top')
                    element.scrollTo(element.scrollLeft, newScroll);
                else
                    element.scrollTo(newScroll, element.scrollTop);
            }
            else {
                if (direction === 'top')
                    element.scrollTop = newScroll;
                else
                    element.scrollLeft = newScroll;
            }
        }), 1000 / 60);
        return timer;
    }
}
Helper.decorators = [
    { type: Injectable }
];
/** @nocollapse */
Helper.ctorParameters = () => [
    { type: ComponentFactoryResolver },
    { type: ApplicationRef },
    { type: Injector }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SliderCarouselComponent {
    /**
     * @param {?} renderer
     * @param {?} helper
     */
    constructor(renderer, helper) {
        this.renderer = renderer;
        this.helper = helper;
        this.class = true;
        this.images = [];
        this.preview = true;
        this.height = '500px';
        this.width = '100%';
        this.maxWidth = '100%';
        this.autoSize = false;
        this.initialized = false;
        this.currentImageIndex = 0;
        this.lastDirectionIsRight = false;
        this.containerWidth = 0;
        this.destroyed = false;
        this.windowResizing = false;
        this.listeners = [];
        this.drag = {
            state: 'none',
            // 'start', 'dragging', 'none'
            startOffset: 0,
            currentOffset: 0,
            startLeft: 0,
            currentLeft: 0,
        };
    }
    /**
     * @return {?}
     */
    get currentImage() { return this.images[this.currentImageIndex]; }
    /**
     * @return {?}
     */
    get currentIsFisrt() { return this.currentImageIndex === 0; }
    /**
     * @return {?}
     */
    get currentIsLast() { return this.currentImageIndex === (this.images.length - 1); }
    /**
     * @return {?}
     */
    get isDragging() { return this.drag.state !== 'none'; }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        this.prepare();
    }
    /**
     * @private
     * @return {?}
     */
    prepare() {
        if (typeof this.height !== 'string')
            this.height = '500px';
        else if (!this.height.endsWith('%') && !this.height.endsWith('px'))
            this.height += 'px';
        if (typeof this.width !== 'string')
            this.width = '100%';
        else if (!this.width.endsWith('%') && !this.width.endsWith('px'))
            this.width += 'px';
        if (typeof this.maxWidth !== 'string')
            this.maxWidth = '100%';
        else if (!this.maxWidth.endsWith('%') && !this.maxWidth.endsWith('px'))
            this.maxWidth += 'px';
        this.initialized = true;
        this.checkImages();
        this.initSlideDragWatching();
        this.defineContainerWidth();
    }
    /**
     * @private
     * @return {?}
     */
    checkImages() {
        if (this.images && this.images.length) {
            if (typeof this.images[0] !== 'string') {
                ((/** @type {?} */ (this.images))).forEach((/**
                 * @param {?} image
                 * @return {?}
                 */
                (image) => {
                    if (!image.md)
                        image.md = image.lg;
                    if (!image.sm)
                        image.sm = image.md;
                }));
            }
            else
                this.images = ((/** @type {?} */ (this.images))).map((/**
                 * @param {?} image
                 * @return {?}
                 */
                (image) => {
                    return { lg: image, md: image, sm: image };
                }));
        }
    }
    /**
     * @private
     * @return {?}
     */
    initSlideDragWatching() {
        if (this.innerImagesEl && this.innerImagesEl.nativeElement) {
            if (this.listeners && this.listeners.length)
                this.listeners.forEach((/**
                 * @param {?} unListen
                 * @return {?}
                 */
                (unListen) => unListen()));
            this.listeners = [
                this.renderer.listen(window, 'mousedown', this.onStartDrag.bind(this)),
                this.renderer.listen(window, 'touchstart', this.onStartDrag.bind(this)),
                this.renderer.listen(window, 'mousemove', this.onDragging.bind(this)),
                this.renderer.listen(window, 'touchmove', this.onDragging.bind(this)),
                this.renderer.listen(window, 'mouseup', this.onEndDrag.bind(this)),
                this.renderer.listen(window, 'touchend', this.onEndDrag.bind(this))
            ];
        }
        else
            setTimeout((/**
             * @return {?}
             */
            () => this.initSlideDragWatching()), 200);
    }
    /**
     * @private
     * @return {?}
     */
    defineContainerWidth() {
        if (this.destroyed)
            return;
        if (!this.windowResizing) {
            /** @type {?} */
            let width = 0;
            if (this.sectionEl && this.sectionEl.nativeElement)
                width = this.sectionEl.nativeElement.clientWidth;
            if (width !== this.containerWidth)
                this.containerWidth = width;
        }
        setTimeout(this.defineContainerWidth.bind(this), 100);
    }
    /**
     * @param {?} image
     * @return {?}
     */
    previewImage(image) {
        if (!this.previewRef) {
            this.previewRef = this.helper.openPreview({
                imageUrl: image.lg
            });
            this.previewRef.onClose.subscribe((/**
             * @return {?}
             */
            () => this.previewRef = null));
        }
    }
    /**
     * @param {?} imageIndex
     * @param {?} event
     * @return {?}
     */
    selectImage(imageIndex, event) {
        if (imageIndex !== this.currentImageIndex) {
            this.lastDirectionIsRight = imageIndex > this.currentImageIndex;
            this.currentImageIndex = imageIndex;
            if (event.target && this.imageListEl && this.imageListEl.nativeElement)
                this.scrollingToElement((/** @type {?} */ (event.target)), this.lastDirectionIsRight);
        }
    }
    /**
     * @param {?=} salt
     * @return {?}
     */
    goPrevImage(salt = 0) {
        if (this.currentImageIndex > 0) {
            if (salt) {
                if ((this.currentImageIndex - salt) >= 0)
                    this.currentImageIndex -= salt + 1;
                else
                    this.currentImageIndex = 0;
            }
            else
                this.currentImageIndex--;
            this.lastDirectionIsRight = false;
            /** @type {?} */
            let target = (/** @type {?} */ (this.imageListEl.nativeElement.children[0].children[this.currentImageIndex]));
            if (this.imageListEl && this.imageListEl.nativeElement)
                this.scrollingToElement(target, this.lastDirectionIsRight);
        }
    }
    /**
     * @param {?=} salt
     * @return {?}
     */
    goNextImage(salt = 0) {
        if ((this.currentImageIndex + 1) < this.images.length) {
            if (salt) {
                if ((this.currentImageIndex + salt + 1) <= (this.images.length - 1))
                    this.currentImageIndex = salt + 1;
                else
                    this.currentImageIndex = this.images.length;
            }
            else
                this.currentImageIndex++;
            this.lastDirectionIsRight = true;
            /** @type {?} */
            let target = (/** @type {?} */ (this.imageListEl.nativeElement.children[0].children[this.currentImageIndex]));
            if (this.imageListEl && this.imageListEl.nativeElement)
                this.scrollingToElement(target, this.lastDirectionIsRight);
        }
    }
    /**
     * @private
     * @param {?} element
     * @param {?} directionIsRight
     * @return {?}
     */
    scrollingToElement(element, directionIsRight) {
        /** @type {?} */
        let scrollElement = this.imageListEl.nativeElement;
        if (scrollElement && scrollElement.scrollWidth > 0) {
            /** @type {?} */
            let blockWidth = element.clientWidth + 14;
            /** @type {?} */
            let scrollLeft = element.offsetLeft - 14;
            /** @type {?} */
            let scrollRight = element.offsetLeft + element.clientWidth + 14;
            /** @type {?} */
            let currentScrollLeft = scrollElement.scrollLeft;
            /** @type {?} */
            let currentScrollRight = scrollElement.scrollLeft + scrollElement.clientWidth;
            /** @type {?} */
            let scroll = .1;
            if (directionIsRight && (currentScrollRight - scrollRight) < Math.floor(blockWidth / 2))
                scroll = currentScrollLeft + blockWidth + 100;
            else if (!directionIsRight && (scrollLeft - currentScrollLeft) < Math.floor(blockWidth / 2))
                scroll = currentScrollLeft - blockWidth;
            if (scroll !== .1) {
                if (this.timerSroll)
                    clearInterval(this.timerSroll);
                this.timerSroll = this.helper.smoothScroll(scrollElement, scroll, 400, 'left');
            }
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onKeydown(event) {
        if (!this.destroyed && !this.isDragging && [37, 39].indexOf(event.keyCode) >= 0) {
            if (event.keyCode === 37)
                this.goPrevImage();
            else
                this.goNextImage();
            if (this.previewRef)
                this.previewRef.instance.onImageChange(((/** @type {?} */ (this.currentImage))).lg);
        }
    }
    /**
     * @return {?}
     */
    onWindowResize() {
        if (!this.destroyed && !this.windowResizing) {
            this.windowResizing = true;
            setTimeout((/**
             * @return {?}
             */
            () => {
                this.containerWidth = this.sectionEl.nativeElement.clientWidth;
                this.windowResizing = false;
                setTimeout((/**
                 * @return {?}
                 */
                () => {
                    if (this.imageListEl && this.imageListEl.nativeElement) {
                        /** @type {?} */
                        let target = (/** @type {?} */ (this.imageListEl.nativeElement.children[0].children[this.currentImageIndex]));
                        if (this.imageListEl && this.imageListEl.nativeElement)
                            this.scrollingToElement(target, this.lastDirectionIsRight);
                    }
                }), 100);
            }));
        }
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    onStartDrag(event) {
        if (event.button === 0) {
            if (event.originalEvent && event.originalEvent.touches)
                event = event.originalEvent.touches[0];
            /** @type {?} */
            let containerBounds = this.sectionEl.nativeElement.getBoundingClientRect();
            /** @type {?} */
            let containerXLeft = containerBounds.left;
            /** @type {?} */
            let containerXRight = containerBounds.left + containerBounds.width;
            /** @type {?} */
            let containerYAbove = containerBounds.top;
            /** @type {?} */
            let containerYBelow = containerBounds.top + containerBounds.height;
            if (event.clientX >= containerXLeft && event.clientX <= containerXRight &&
                event.clientY >= containerYAbove && event.clientY <= containerYBelow) {
                this.drag.startLeft = this.innerImagesEl.nativeElement.offsetLeft;
                this.drag.currentLeft = this.innerImagesEl.nativeElement.offsetLeft;
                this.drag.startOffset = event.clientX;
                this.drag.currentOffset = event.clientX;
                this.drag.state = 'start';
            }
        }
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    onDragging(event) {
        if (this.drag.state === 'start' || this.drag.state === 'dragging') {
            event.preventDefault();
            event.stopImmediatePropagation();
            if (event.originalEvent && event.originalEvent.touches)
                event = event.originalEvent.touches[0];
            this.drag.state = 'dragging';
            this.drag.currentOffset = event.clientX;
            if (this.drag.startOffset !== this.drag.currentOffset) {
                /** @type {?} */
                let draggingRight = this.drag.currentOffset > this.drag.startOffset;
                /** @type {?} */
                let delta = Math.abs(this.drag.currentOffset - this.drag.startOffset) * .8;
                if (((draggingRight && this.currentIsFisrt) || (!draggingRight && this.currentIsLast)) && delta > Math.floor(this.containerWidth / 3))
                    delta = Math.floor(this.containerWidth / 3);
                this.drag.currentLeft = this.drag.startLeft + ((draggingRight ? 1 : -1) * delta);
            }
            else
                this.drag.currentLeft = this.drag.startLeft;
        }
    }
    /**
     * @private
     * @param {?} event
     * @return {?}
     */
    onEndDrag(event) {
        if (event.button === 0) {
            event.preventDefault();
            event.stopImmediatePropagation();
            /** @type {?} */
            let amountDragged = Math.abs(this.drag.startOffset - this.drag.currentOffset);
            if (amountDragged > 0 && this.drag.state === 'dragging')
                setTimeout((/**
                 * @return {?}
                 */
                () => {
                    this.drag.state = 'none';
                    /** @type {?} */
                    let minDreg = 70;
                    if (amountDragged >= minDreg) {
                        /** @type {?} */
                        let draggingRight = this.drag.currentOffset > this.drag.startOffset;
                        /** @type {?} */
                        let salts = (amountDragged / this.sectionEl.nativeElement.clientWidth) - 1;
                        if (salts >= 1)
                            salts = Math.floor(salts);
                        else
                            salts = 0;
                        if (draggingRight && !this.currentIsFisrt)
                            this.goPrevImage(salts);
                        else if (!draggingRight && !this.currentIsLast)
                            this.goNextImage(salts);
                    }
                }));
            else {
                this.drag.state = 'none';
            }
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.destroyed = true;
        if (this.listeners && this.listeners.length)
            this.listeners.forEach((/**
             * @param {?} unListen
             * @return {?}
             */
            (unListen) => unListen()));
    }
}
SliderCarouselComponent.decorators = [
    { type: Component, args: [{
                selector: 'slider-carousel',
                template: "<section #section *ngIf=\"images && images.length\" [style.width]=\"width\" [style.maxWidth]=\"maxWidth\">\r\n    <div [hidden]=\"windowResizing\" *ngIf=\"containerWidth > 0\" class=\"image-controller animated fadeIn\" [style.maxWidth]=\"containerWidth + 'px'\">\r\n\r\n        <!-- INNER CONTAINER -->\r\n        <ul #innerImages *ngIf=\"!autoSize\"\r\n            [ngClass]=\"{'dragging-effect': isDragging}\"\r\n            [style.left]=\"(isDragging ? drag.currentLeft : (-currentImageIndex * containerWidth)) + 'px'\"\r\n            [style.height]=\"height\">\r\n            <li *ngFor=\"let image of images; let i = index;\"\r\n                [style.backgroundImage]=\"'url(' + image.md + ')'\"\r\n                [style.width]=\"containerWidth + 'px'\"\r\n                [ngClass]=\"{'cursor-pointer': preview, 'is-current': i === currentImageIndex}\"\r\n                (click)=\"!isDragging && previewImage(image)\">\r\n            </li>\r\n        </ul>\r\n        <ul #innerImages *ngIf=\"autoSize\"\r\n            [ngClass]=\"{'dragging-effect': isDragging}\"\r\n            [style.left]=\"(isDragging ? drag.currentLeft : (-currentImageIndex * containerWidth)) + 'px'\">\r\n            <div *ngFor=\"let image of images; let i = index;\" [style.width]=\"containerWidth + 'px'\">\r\n                <img [src]=\"image.md\"\r\n                    [ngClass]=\"{'cursor-pointer': preview, 'is-current': i === currentImageIndex}\"\r\n                    (click)=\"!isDragging && previewImage(image)\"\r\n                />\r\n            </div>\r\n        </ul>\r\n\r\n        <!-- NAVIGATION BUTTONS -->\r\n        <div (click)=\"goPrevImage()\" class=\"image-controller-prev\" [ngClass]=\"{'disabled': currentImageIndex <= 0}\" role=\"button\">\r\n            <svg viewBox=\"0 0 456 456\">\r\n                <path d=\"M227.996,0C102.081,0,0,102.081,0,227.996c0,125.945,102.081,227.996,227.996,227.996\r\n\t\t\t\tc125.945,0,227.996-102.051,227.996-227.996C455.992,102.081,353.941,0,227.996,0z M299.435,238.788l-98.585,98.585\r\n\t\t\t\tc-5.928,5.897-15.565,5.897-21.492,0c-5.928-5.928-5.928-15.595,0-21.492l87.885-87.885l-87.885-87.885\r\n\t\t\t\tc-5.928-5.928-5.928-15.565,0-21.492s15.565-5.928,21.492,0l98.585,98.585c3.04,2.979,4.469,6.901,4.438,10.792\r\n\t\t\t\tC303.873,231.918,302.414,235.809,299.435,238.788z\"/>\r\n            </svg>                    \r\n        </div>\r\n        <div (click)=\"goNextImage()\" class=\"image-controller-next\" [ngClass]=\"{'disabled': (currentImageIndex + 1) >= images.length}\" role=\"button\">\r\n            <svg viewBox=\"0 0 456 456\">\r\n                <path d=\"M227.996,0C102.081,0,0,102.081,0,227.996c0,125.945,102.081,227.996,227.996,227.996\r\n\t\t\t\tc125.945,0,227.996-102.051,227.996-227.996C455.992,102.081,353.941,0,227.996,0z M299.435,238.788l-98.585,98.585\r\n\t\t\t\tc-5.928,5.897-15.565,5.897-21.492,0c-5.928-5.928-5.928-15.595,0-21.492l87.885-87.885l-87.885-87.885\r\n\t\t\t\tc-5.928-5.928-5.928-15.565,0-21.492s15.565-5.928,21.492,0l98.585,98.585c3.04,2.979,4.469,6.901,4.438,10.792\r\n\t\t\t\tC303.873,231.918,302.414,235.809,299.435,238.788z\"/>\r\n            </svg>  \r\n        </div>\r\n\r\n    </div>\r\n\r\n    <!-- GALLERY NAVIGATION -->\r\n    <div [hidden]=\"windowResizing\" *ngIf=\"!windowResizing && containerWidth > 0\" #imageList class=\"footer-images animated fadeIn\" [style.maxWidth]=\"containerWidth + 'px'\">\r\n        <ul>\r\n            <li matRipple (click)=\"selectImage(i, $event)\" *ngFor=\"let image of images; let i = index;\"\r\n                [ngClass]=\"{'is-current': i === currentImageIndex}\"\r\n                [style.backgroundImage]=\"'url(' + image.sm + ')'\">\r\n            </li>\r\n        </ul>\r\n    </div>\r\n</section>",
                host: {
                    '(document:keydown)': 'onKeydown($event)',
                    '(window:resize)': 'onWindowResize()'
                }
            }] }
];
/** @nocollapse */
SliderCarouselComponent.ctorParameters = () => [
    { type: Renderer2 },
    { type: Helper }
];
SliderCarouselComponent.propDecorators = {
    class: [{ type: HostBinding, args: ['class.slider-carousel',] }],
    sectionEl: [{ type: ViewChild, args: ['section',] }],
    imageListEl: [{ type: ViewChild, args: ['imageList',] }],
    innerImagesEl: [{ type: ViewChild, args: ['innerImages',] }],
    images: [{ type: Input }],
    preview: [{ type: Input }],
    height: [{ type: Input }],
    width: [{ type: Input }],
    maxWidth: [{ type: Input, args: ['max-width',] }],
    autoSize: [{ type: Input, args: ['auto-size',] }]
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SliderCarouselModule {
}
SliderCarouselModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                ],
                exports: [
                    SliderCarouselComponent
                ],
                declarations: [
                    SliderCarouselComponent,
                    SliderCarouselPreviewComponent
                ],
                entryComponents: [
                    SliderCarouselComponent,
                    SliderCarouselPreviewComponent
                ],
                providers: [
                    Helper
                ]
            },] }
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { SliderCarouselModule, SliderCarouselComponent, Helper as ɵa, SliderCarouselPreviewComponent as ɵb };

//# sourceMappingURL=slider-carousel.js.map